.. _howtos:

################
NumPy How Tos
################

These documents are intended as recipes to common tasks using NumPy. For
detailed reference documentation of the functions and classes contained in
the package, see the :ref:`API reference <reference>`.

.. toctree::
   :maxdepth: 1

   how-to-how-to
   how-to-io
   how-to-index
